@@ -38,12 +38,13 @@ class GNode:
         g_node_registry_addr: str,
         prev_alias: Optional[str] = None,
         gps_point_id: Optional[str] = None,
-        ownership_deed_nft_id: Optional[int] = None,
+        ownership_deed_id: Optional[int] = None,
         ownership_deed_validator_addr: Optional[str] = None,
         owner_addr: Optional[str] = None,
         daemon_addr: Optional[str] = None,
-        trading_rights_nft_id: Optional[int] = None,
+        trading_rights_id: Optional[int] = None,
         scada_algo_addr: Optional[str] = None,
+        scada_cert_id: Optional[int] = None,
         component_id: Optional[str] = None,
         display_name: Optional[str] = None,
     ):
@@ -57,12 +58,13 @@ class GNode:
             g_node_registry_addr (str): _description_
             prev_alias (Optional[str], optional): _description_. Defaults to None.
             gps_point_id (Optional[str], optional): _description_. Defaults to None.
-            ownership_deed_nft_id (Optional[int], optional): _description_. Defaults to None.
+            ownership_deed_id (Optional[int], optional): _description_. Defaults to None.
             ownership_deed_validator_addr (Optional[str], optional): _description_. Defaults to None.
             owner_addr (Optional[str], optional): _description_. Defaults to None.
             daemon_addr (Optional[str], optional): _description_. Defaults to None.
-            trading_rights_nft_id (Optional[int], optional): _description_. Defaults to None.
+            trading_rights_id (Optional[int], optional): _description_. Defaults to None.
             scada_algo_addr ()(Optional[str], optional): _description_. Defaults to None.
+            scada_cert_id (Optional[int], optional): _description_. Defaults to None.
             component_id (Optional[str], optional): _description_. Defaults to None.
             display_name (Optional[str], optional): _description_. Defaults to None.
 
@@ -80,20 +82,21 @@ class GNode:
         self.g_node_registry_addr = g_node_registry_addr
         self.prev_alias = prev_alias
         self.gps_point_id = gps_point_id
-        self.ownership_deed_nft_id = ownership_deed_nft_id
+        self.ownership_deed_id = ownership_deed_id
         self.ownership_deed_validator_addr = ownership_deed_validator_addr
         self.owner_addr = owner_addr
         self.daemon_addr = daemon_addr
-        self.trading_rights_nft_id = trading_rights_nft_id
+        self.trading_rights_id = trading_rights_id
         self.scada_algo_addr = scada_algo_addr
+        self.scada_cert_id = scada_cert_id
         self.component_id = component_id
         self.display_name = display_name
         self.__class__.by_alias[self.alias] = self
 
     def __repr__(self) -> str:
         rs = f"GNode Alias: {self.alias}, Role: {self.role.value}, Status: {self.status.value}"
-        if self.ownership_deed_nft_id and self.role == GNodeRole.TerminalAsset:
-            rs += f", TaDeedIdx: {self.ownership_deed_nft_id}"
+        if self.ownership_deed_id and self.role == GNodeRole.TerminalAsset:
+            rs += f", TaDeedIdx: {self.ownership_deed_id}"
         return rs
 
     def gps_point(self) -> Optional[GpsPoint]:
